==> bigloo_1.9c.orig.tar.gz: bigloo1.9c/comptime/Write/scheme.scm <==
;* --------------------------------------------------------------------*/
;*    Copyright (c) 1992-1998 by Manuel Serrano. All rights reserved.  */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \   /  '                               */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome. Send them to                                          */
;*        Manuel Serrano -- Manuel.Serrano@unice.fr                    */
;*-------------------------------------------------------------------- */
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime1.9/Write/scheme.scm         */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Dec 28 15:07:23 1994                          */
;*    Last change :  Thu Jun 13 14:44:25 1996 (serrano)                */
;*    -------------------------------------------------------------    */
;*    Some tools to write Scheme code.                                 */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module write_scheme
   (import engine_param)
   (export (write-scheme-file-header ::output-port string)
	   (write-scheme-comment     ::output-port . sexp)))

;*---------------------------------------------------------------------*/
;*    write-scheme-file-header ...                                     */
;*---------------------------------------------------------------------*/
(define (write-scheme-file-header port string)
   (fprint port ";; =========================================================")
   (fprint port ";; " string)
   (fprint port ";; " *bigloo-name*)
   (fprint port ";; " *bigloo-author* " (c)      " *bigloo-date*)
   (fprint port ";; =========================================================")
   (newline port))

;*---------------------------------------------------------------------*/
;*    write-scheme-comment ...                                         */
;*---------------------------------------------------------------------*/
(define (write-scheme-comment port . sexp)
   (cond
      ((null? sexp)
       (fprint port ";;"))
      ((null? (cdr sexp))
       (fprint port ";; " (car sexp)))
      (else
       (apply fprint (cons* port ";; " sexp)))))

==> bigloo_2.8c.orig.tar.gz: bigloo2.8c/comptime/Write/scheme.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Write/scheme.scm            */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Dec 28 15:07:23 1994                          */
;*    Last change :  Sat Mar 24 08:34:09 2001 (serrano)                */
;*    Copyright   :  1994-2001 Manuel Serrano, see LICENSE file        */
;*    -------------------------------------------------------------    */
;*    Some tools to write Scheme code.                                 */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module write_scheme
   (import engine_param)
   (export (write-scheme-file-header ::output-port string)
	   (write-scheme-comment     ::output-port . sexp)))

;*---------------------------------------------------------------------*/
;*    write-scheme-file-header ...                                     */
;*---------------------------------------------------------------------*/
(define (write-scheme-file-header port string)
   (fprint port ";; =========================================================")
   (fprint port ";; " string)
   (fprint port ";; " *bigloo-name*)
   (fprint port ";; " *bigloo-author* "       " *bigloo-date*)
   (fprint port ";; =========================================================")
   (newline port))

;*---------------------------------------------------------------------*/
;*    write-scheme-comment ...                                         */
;*---------------------------------------------------------------------*/
(define (write-scheme-comment port . sexp)
   (cond
      ((null? sexp)
       (fprint port ";;"))
      ((null? (cdr sexp))
       (fprint port ";; " (car sexp)))
      (else
       (apply fprint port ";; " sexp))))
